##########
Gallary
##########


Here are some flexible practical examples of trackc

Advanced Science
=================

.. nbgallery::
    :caption: rearranged heatmaps 1:
    :name: rst-gallery
    :glob:
    :reversed:

    examples/zoomin_heatmap
    examples/mapc_eg

feng yue
==========

.. nbgallery::
    :caption: neo-domain:
    :name: rst-gallary
    :glob:
    :reversed:

    examples/zoomin_heatmap
    